==> haskell-numbers-3000.2.0.2-45-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-G0cB2iObsWE6Zo6R2XxtGj
key:                  numbers-3000.2.0.2-G0cB2iObsWE6Zo6R2XxtGj
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  581357964cc4979c53c32fb759873c29
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-G0cB2iObsWE6Zo6R2XxtGj
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-numbers-3000.2.0.2-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-numbers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 numbers
version:              3000.2.0.2
visibility:           public
id:                   numbers-3000.2.0.2-5QWetMH9G516eOK34kzIvi
key:                  numbers-3000.2.0.2-5QWetMH9G516eOK34kzIvi
license:              BSD-3-Clause
maintainer:           johnw@newartisans.com
author:               Lennart Augustsson
homepage:             https://github.com/jwiegley/numbers#readme
synopsis:             Various number types
description:
    Instances of the numerical classes for a variety of
    different numbers: (computable) real numbers,
    arbitrary precision fixed numbers,
    arbitrary precision floating point numbers,
    differentiable numbers, symbolic numbers,
    natural numbers, interval arithmetic.

category:             Data, Math
abi:                  3bba98a10046f4e30dcae7ec090fae0e
exposed:              True
exposed-modules:
    Data.Number.BigFloat Data.Number.CReal Data.Number.Dif
    Data.Number.Fixed Data.Number.FixedFunctions Data.Number.Interval
    Data.Number.Natural Data.Number.Symbolic Data.Number.Vectorspace

import-dirs:          /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/numbers-3000.2.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-numbers
hs-libraries:         HSnumbers-3000.2.0.2-5QWetMH9G516eOK34kzIvi
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-numbers/html/numbers.haddock
haddock-html:         /usr/share/doc/haskell-numbers/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
